crikit.io package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   crikit.io.lazy5
   crikit.io.tests

Submodules
----------

crikit.io.csv\_nist module
--------------------------

.. automodule:: crikit.io.csv_nist
   :members:
   :undoc-members:
   :show-inheritance:

crikit.io.hdf5 module
---------------------

.. automodule:: crikit.io.hdf5
   :members:
   :undoc-members:
   :show-inheritance:

crikit.io.macros module
-----------------------

.. automodule:: crikit.io.macros
   :members:
   :undoc-members:
   :show-inheritance:

crikit.io.meta\_configs module
------------------------------

.. automodule:: crikit.io.meta_configs
   :members:
   :undoc-members:
   :show-inheritance:

crikit.io.meta\_process module
------------------------------

.. automodule:: crikit.io.meta_process
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: crikit.io
   :members:
   :undoc-members:
   :show-inheritance:
